@@ -1,8 +1,9 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 import datetime
+
 from trytond.model import ModelSQL, fields
-from trytond.pool import PoolMeta, Pool
+from trytond.pool import Pool, PoolMeta
 from trytond.transaction import Transaction
 
 
@@ -45,7 +46,7 @@ class ProductSupplierDay(ModelSQL):
     __name__ = 'purchase.product_supplier.day'
     product_supplier = fields.Many2One(
         'purchase.product_supplier', 'Supplier',
-        required=True, ondelete='CASCADE', select=True)
+        required=True, ondelete='CASCADE')
     day = fields.Many2One('ir.calendar.day', "Day", required=True)
 
     @classmethod
